# Potato.py - Python Project Template

Potato.py is a Python project template designed to simplify the creation of Python projects, especially those involving database connectivity with PostgreSQL, MySQL, and Oracle. Additionally, it provides tools to create GUI systems quickly, enabling you to kickstart your projects with ease.

## Features

- **Database Connectivity**: Easily connect your Python projects to PostgreSQL, MySQL, and Oracle databases.
- **GUI System**: Quickly create graphical user interfaces for your applications, reducing development time.
- **Project Structure**: Organized project structure to streamline development and maintenance.
- **Easy Setup**: Get started with your Python projects quickly, thanks to the simple setup process.
- **Documentation**: Detailed documentation to guide you through the project setup and usage.

## Getting Started

To use Potato.py for your Python projects, follow these steps:

1. **Clone the Repository**: Clone the Potato.py repository to your local machine.

```bash
git clone https://github.com/yourusername/potato.py.git
```

2. **Setup Database Connectivity**: Configure database connections in the `config.py` file.

3. **Create Your Project**: Use the Potato.py template to create your Python project.

4. **Develop Your Application**: Start building your Python application, leveraging the provided database connectivity and GUI system.

5. **Run Your Application**: Test and run your application to ensure everything works as expected.

## Usage

### Database Connectivity

Potato.py provides simple methods to connect your Python application to various databases:

```python
import potato

# Connect to PostgreSQL
pg_connection = potato.connect_to_postgresql(host='localhost', database='mydatabase', user='myuser', password='mypassword')

# Connect to MySQL
mysql_connection = potato.connect_to_mysql(host='localhost', database='mydatabase', user='myuser', password='mypassword')

# Connect to Oracle
oracle_connection = potato.connect_to_oracle(host='localhost', database='mydatabase', user='myuser', password='mypassword')
```

### GUI System

Potato.py includes tools to create GUI systems quickly using popular libraries such as Tkinter:

```python
import potato

# Create a basic GUI window
window = potato.create_window(title='My App', width=800, height=600)

# Add widgets to the window
label = potato.create_label(window, text='Hello, World!')
button = potato.create_button(window, text='Click Me', command=handle_click)

# Run the GUI event loop
potato.run_gui()
```


To make your Python module into one line, you can use a tool like `python -m py_compile <your_script.py>` to compile the script into bytecode, and then use a tool like `base64` to encode the bytecode into a single line. Here's a step-by-step process:

1. **Compile your script into bytecode**:
   Use the Python built-in module `py_compile` to compile your script into bytecode. Run the following command in your terminal:

   ```
   python -m py_compile your_script.py
   ```

   This will create a bytecode file with a `.pyc` extension in the same directory as your script.

2. **Encode the bytecode into base64**:
   Next, you can use `base64` to encode the bytecode file into a single line. Run the following command in your terminal:

   ```
   base64 -w 0 your_script.pyc
   ```

   The `-w 0` flag ensures that the output is not split into multiple lines.

3. **Embed the base64-encoded bytecode**:
   You can now take the output of the `base64` command and embed it directly into your Python script as a string. For example:

   ```python
   import base64
   exec(base64.b64decode('''
   <base64-encoded-bytecode-here>
   '''))
   ```

   Replace `<base64-encoded-bytecode-here>` with the output generated by the `base64` command.

4. **Optional: Delete the original bytecode file**:
   Once you've embedded the base64-encoded bytecode into your script, you can delete the original `.pyc` file if you no longer need it.

Keep in mind that while this approach makes your module into one line, it also makes it less readable and harder to maintain. Use it judiciously and consider the implications for collaboration and debugging.

For more information on how to use Potato.py, refer to the documentation included with the template.

## Contributing

Contributions to Potato.py are welcome! If you have suggestions for improvements or new features, feel free to open an issue or submit a pull request.

## License

This project is licensed under the MIT License - see the [LICENSE](LICENSE) file for details.
